## Header section ## ----
rm(list=(ls()))
setwd("~/Documents/Synecho Growth Data/")
library(ggplot2)

## Importing and formatting the data
Data <- read.csv("BSA.standard.curve.csv",header = F,row.names = 1, stringsAsFactors = F)
dat <- as.data.frame(t(Data))
dat$Replicate <- as.factor(dat$Replicate)

## Plot
p <- ggplot(dat, aes(x = `Conc.mg.ml-1`, y = Absorbance.590)) +   theme_bw() + 
  geom_smooth(method = "lm", formula = y~poly(x,3), colour="darkgrey", alpha = 0.2) + 
  geom_point(aes(x = `Conc.mg.ml-1`, y = Absorbance.590, colour = Replicate)) +
  ggtitle("BSA \n Bradford assay - Standard curve") + 
  xlab(bquote("Concentration (" *"mg"~ml^-1*")")) + ylim(c(0,1.5)) +
  ylab(bquote("Absorbance ("*A[590]*")")) + scale_colour_grey()

## Adding the model to the plot
model <- lm(dat$Absorbance.590~poly(dat$`Conc.mg.ml-1`,3,raw=T))
coef <- round(model$coefficients, digits=2)
Curve <- paste(coef[1], " + ", coef[2], "*x", " + ", 
               coef[3], "*x^2", " + ", coef[4], "*x^3", sep = "")
p2 <- p + annotate("text", label=Curve, x = 0.3, y=1.25, size=4, parse=T)

## Exporting the figure
pdf("BSA_curve.pdf", width=6)
print(p2)
dev.off()

#### BG-11

## Importing and formatting the data
Data <- read.csv("BG11.curve.csv",header = F,row.names = 1, stringsAsFactors = F)
dat <- as.data.frame(t(Data))
dat$Replicate <- as.factor(dat$Replicate)

## Plot
p <- ggplot(dat, aes(x = `Conc.mg.ml-1`, y = Absorbance.590)) +   theme_bw() + 
  geom_smooth(method = "lm", formula = y~poly(x,3), colour="darkgrey", alpha = 0.2) + 
  geom_point(aes(x = `Conc.mg.ml-1`, y = Absorbance.590, colour = Replicate)) +
  ggtitle("Synechocystis proteins (BG11) \n Bradford assay on dilution series") + 
  xlab(bquote("Dilution")) + ylim(c(0,1.5)) +
  ylab(bquote("Absorbance ("*A[590]*")")) + scale_colour_grey()

## Adding the model to the plot
model <- lm(dat$Absorbance.590~poly(dat$`Conc.mg.ml-1`,3,raw=T))
coef <- round(model$coefficients, digits=2)
Curve <- paste(coef[1], " + ", coef[2], "*x", " + ", 
               coef[3], "*x^2", " + ", coef[4], "*x^3", sep = "")
p2 <- p + annotate("text", label=Curve, x = 0.3, y=1.25, size=4, parse=T)

## Exporting the figure
pdf("BG11_curve.pdf", width=6)
print(p2)
dev.off()

#### BU

## Importing and formatting the data
Data <- read.csv("BU.curve.csv",header = F,row.names = 1, stringsAsFactors = F)
dat <- as.data.frame(t(Data))
dat$Replicate <- as.factor(dat$Replicate)

## Plot
p <- ggplot(dat, aes(x = `Conc.mg.ml-1`, y = Absorbance.590)) +   theme_bw() + 
  geom_smooth(method = "lm", formula = y~poly(x,3), colour="darkgrey", alpha = 0.2) + 
  geom_point(aes(x = `Conc.mg.ml-1`, y = Absorbance.590, colour = Replicate)) +
  ggtitle("Synechocystis proteins (Bu) \n Bradford assay on dilution series") + 
  xlab(bquote("Dilution")) + ylim(c(0,1.5)) +
  ylab(bquote("Absorbance ("*A[590]*")")) + scale_colour_grey()

## Adding the model to the plot
model <- lm(dat$Absorbance.590~poly(dat$`Conc.mg.ml-1`,3,raw=T))
coef <- round(model$coefficients, digits=2)
Curve <- paste(coef[1], " + ", coef[2], "*x", " + ", 
               coef[3], "*x^2", " + ", coef[4], "*x^3", sep = "")
p2 <- p + annotate("text", label=Curve, x = 0.3, y=1.25, size=4, parse=T)

## Exporting the figure
pdf("BU_curve.pdf", width=6)
print(p2)
dev.off()

### Combined media synechocystis data

Data <- read.csv("BU.curve.csv",header = F,row.names = 1, stringsAsFactors = F)
Data2 <- read.csv("BG11.curve.csv",header = F,row.names = 1, stringsAsFactors = F)
dat <- as.data.frame(t(Data))
dat <- rbind(dat,as.data.frame(t(Data2)))
dat$Replicate <- as.factor(dat$Replicate)
dat$Media <- c(rep("Bu",24),rep("BG",24))

## Plot
p <- ggplot(dat, aes(x = `Conc.mg.ml-1`, y = Absorbance.590, colour=Media)) +   theme_bw() + 
  geom_smooth(method = "lm", formula = y~poly(x,3), colour="darkgrey", alpha = 0.2) + 
  geom_point(aes(x = `Conc.mg.ml-1`, y = Absorbance.590, colour = Media)) +
  ggtitle("Synechocystis proteins \n Bradford assay on dilution series") + 
  xlab(bquote("Dilution")) + ylim(c(0,1.5)) +
  ylab(bquote("Absorbance ("*A[590]*")")) + scale_colour_grey()

## Adding the model to the plot
model <- lm(dat$Absorbance.590~poly(dat$`Conc.mg.ml-1`,3,raw=T))
coef <- round(model$coefficients, digits=2)
Curve <- paste(coef[1], " + ", coef[2], "*x", " + ", 
               coef[3], "*x^2", " + ", coef[4], "*x^3", sep = "")
p2 <- p + annotate("text", label=Curve, x = 0.3, y=1.25, size=4, parse=T)

## Exporting the figure
pdf("Syn_curve.pdf", width=6)
print(p2)
dev.off()
